@@ -4,6 +4,6 @@ from . import views
 
 app_name = 'netbox_attachments'
 router = NetBoxRouter()
-router.register('netbox_attachments', views.NetBoxAttachmentViewSet)
+router.register('netbox-attachments', views.NetBoxAttachmentViewSet)
 
 urlpatterns = router.urls
